@@ -1,4 +1,5 @@
 """Offer common helper functions for the CLI."""
+import asyncio
 import logging
 import time
 
@@ -38,14 +39,25 @@ def run_gateway(gateway):
         gateway.stop()
 
 
-def run_async_gateway(gateway, stop_task=None):
+def run_async_gateway(gateway_factory):
     """Run an async gateway."""
     try:
-        gateway.tasks.loop.run_until_complete(gateway.start_persistence())
-        gateway.tasks.loop.run_until_complete(gateway.start())
-        gateway.tasks.loop.run_forever()
+        asyncio.run(handle_async_gateway(gateway_factory))
     except KeyboardInterrupt:
-        gateway.tasks.loop.run_until_complete(gateway.stop())
+        pass
+
+
+async def handle_async_gateway(gateway_factory):
+    """Handle gateway."""
+    gateway, stop_task = await gateway_factory()
+    await gateway.start_persistence()
+    await gateway.start()
+
+    try:
+        while True:
+            await asyncio.sleep(0.5)
+    except asyncio.CancelledError:
+        await gateway.stop()
         if stop_task:
-            gateway.tasks.loop.run_until_complete(stop_task)
-        gateway.tasks.loop.close()
+            await stop_task()
+        raise
